/**
 * Main site Layout
 */
import React from "react"
import Helmet from "react-helmet"
import { useStaticQuery, graphql } from "gatsby"
import SEO from "./seo"
import Header from "../components/Header"
import Footer from "../components/Footer"
import { SideBar } from "@onegeo-suite/gatsby-theme-onegeo"
interface Props {
    children: React.ReactNode
    UserMenu?: React.ReactNode
    theme?: string
    documents?: object[]
    links?: object[]
}

/**
 * Default Layout with Header (Helmet & SEO) and Footer
 * @param {Props} props - Page content
 * @returns {JSX.Element} The complete page
 */
const Layout = ({
    children,
    theme,
    documents = [],
    links = [],
}: Props): JSX.Element => {
    const data = useStaticQuery(graphql`
        query {
            directus {
                site {
                    icon {
                        id
                        imageFile {
                            id
                            publicURL
                        }
                    }
                }
            }
        }
    `)

    let position = "right"

    return (
        <>
            <Helmet>
                <link
                    rel="icon"
                    href={data.directus.site?.icon?.imageFile?.publicURL}
                    type="image/png"
                />
            </Helmet>
            <SEO />
            {/* 
                Header is fixed (need to reserve space on page top)
                Footer is always displayed at the bottom of the page
                https://www.freecodecamp.org/news/how-to-keep-your-footer-where-it-belongs-59c6aa05c59c
            */}
            <div
                className="bg-base-100 text-base-content relative min-h-screen"
                data-theme={theme}
            >
                {/* 
                    pt-16 : header height
                    pb-24 : footer height
                 */}
                <div className="pb-24 pt-16">
                    <Header />
                    {documents.length > 0 || links.length > 0 ? (
                        <div className="mb-8 mt-8 flex h-full flex-wrap gap-6 md:flex-nowrap">
                            {position === "left" ? (
                                <SideBar documents={documents} links={links} />
                            ) : null}
                            {children}
                            {position === "right" ? (
                                <SideBar documents={documents} links={links} />
                            ) : null}
                        </div>
                    ) : (
                        <>{children}</>
                    )}
                </div>
                <Footer className="absolute bottom-0 h-24" />
            </div>
        </>
    )
}

export default Layout
